==> ejc-prjfinance-impl-3.0.1-20210806.084317-83-sources.jar: com/ejianc/business/prjfinance/bean/ProjectDutyLetterCostlistEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.math.BigDecimal;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * <p>
 * 项目目标责任书--费用清单
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
@TableName("ejc_prjfinance_dutyletter_costlist")
public class ProjectDutyLetterCostlistEntity extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 费用名称
     */
    @TableField("cost_id")
    private Long costId;

    /**
     * 费用名称
     */
    @TableField("cost_name")
    private String costName;

    /**
     * 增加/扣除
     */
    @TableField("back_or_del")
    private String backOrDel;

    /**
     * 数值
     */
    @TableField("formula")
    private String formula;

    /**
     * 公式--实际值
     */
    @TableField("formula_describe")
    private String formulaDescribe;

    /**
     * 金额
     */
    @TableField("amount")
    private BigDecimal amount;

    /**
     * 备注
     */
    @TableField("remarks")
    private String remarks;
    
    /**
     * 主表id
     */
    @TableField("duty_letter_id")
    private Long dutyLetterId;
    
    /**
     * 项目id
     */
	@TableField(exist = false)
    private Long projectId;
    
	public String getCostName() {
		return costName;
	}

	public void setCostName(String costName) {
		this.costName = costName;
	}

	public Long getCostId() {
		return costId;
	}

	public void setCostId(Long costId) {
		this.costId = costId;
	}

	public String getBackOrDel() {
		return backOrDel;
	}

	public void setBackOrDel(String backOrDel) {
		this.backOrDel = backOrDel;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public String getFormulaDescribe() {
		return formulaDescribe;
	}

	public void setFormulaDescribe(String formulaDescribe) {
		this.formulaDescribe = formulaDescribe;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public Long getDutyLetterId() {
		return dutyLetterId;
	}

	public void setDutyLetterId(Long dutyLetterId) {
		this.dutyLetterId = dutyLetterId;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}
	
}

==> ejc-prjfinance-impl-3.0.1-20250821.090535-161-sources.jar: com/ejianc/business/prjfinance/bean/ProjectDutyLetterCostlistEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.math.BigDecimal;
import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * <p>
 * 项目目标责任书--费用清单
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
@TableName("ejc_prjfinance_dutyletter_costlist")
public class ProjectDutyLetterCostlistEntity extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 费用名称
     */
    @TableField("cost_id")
    private Long costId;

    /**
     * 费用名称
     */
    @TableField("cost_name")
    private String costName;

    /**
     * 增加/扣除
     */
    @TableField("back_or_del")
    private String backOrDel;

    /**
     * 数值
     */
    @TableField("formula")
    private String formula;

    /**
     * 公式--实际值
     */
    @TableField("formula_describe")
    private String formulaDescribe;

    /**
     * 金额
     */
    @TableField("amount")
    private BigDecimal amount;

    /**
     * 备注
     */
    @TableField("remarks")
    private String remarks;
    
    /**
     * 主表id
     */
    @TableField("duty_letter_id")
    private Long dutyLetterId;
    
    /**
     * 项目id
     */
	@TableField(exist = false)
    private Long projectId;
	@TableField("cost_code")
	private String costCode;
	@TableField("cost_time")
	private Date costTime;
	@TableField("tax_cost_id")
	private Long taxCostId;

	public String getCostName() {
		return costName;
	}

	public void setCostName(String costName) {
		this.costName = costName;
	}

	public Long getCostId() {
		return costId;
	}

	public void setCostId(Long costId) {
		this.costId = costId;
	}

	public String getBackOrDel() {
		return backOrDel;
	}

	public void setBackOrDel(String backOrDel) {
		this.backOrDel = backOrDel;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public String getFormulaDescribe() {
		return formulaDescribe;
	}

	public void setFormulaDescribe(String formulaDescribe) {
		this.formulaDescribe = formulaDescribe;
	}

	public BigDecimal getAmount() {
		return amount;
	}

	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	public String getCostCode() {
		return costCode;
	}

	public Long getTaxCostId() {
		return taxCostId;
	}

	public void setTaxCostId(Long taxCostId) {
		this.taxCostId = taxCostId;
	}

	public void setCostCode(String costCode) {
		this.costCode = costCode;
	}

	public Date getCostTime() {
		return costTime;
	}

	public void setCostTime(Date costTime) {
		this.costTime = costTime;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public Long getDutyLetterId() {
		return dutyLetterId;
	}

	public void setDutyLetterId(Long dutyLetterId) {
		this.dutyLetterId = dutyLetterId;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}
	
}
